      PROGRAM DenSum  
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c
c DenSum: a code for calculating sums and densities of states.
c Copyright (C) 2006, 2007 John R. Barker
c
c John R. Barker
c jrbarker@umich.edu
c University of Michigan
c Ann Arbor, MI 48109-2143
c (734) 763 6239
c
c This program is free software; you can redistribute it and/or
c modify it under the terms of the GNU General Public License (version 2)
c as published by the Free Software Foundation.
c
c This program is distributed in the hope that it will be useful, 
c but WITHOUT ANY WARRANTY; without even the implied warranty of
c MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
c GNU General Public License for more details.
c
c See the 'ReadMe' file for a copy of the GNU General Public License,
c or contact:
c
c Free Software Foundation, Inc.
c 59 Temple Place - Suite 330
c Boston, MA 02111-1307, USA.
c
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c
C    USES STEIN-RABINOVITCH or WHITTEN-RABINOVITCH FOR COUNTING STATES
C
C    COMPUTES SUMS AND DENSITIES FOR MORSE OSCILLATORS AND
C    FOR HARMONIC OSCILLATORS, USES TROE APPROXIMATION FOR FREE ROTORS
C
C    IF ANH = 0.0, HARMONIC OSCILLATORS ARE ASSUMED
C
C
C    ALL ENERGIES AND FREQUENCIES IN CM-1
C
C
c	Data file format
c
c	LINE
c	1	TITLE (CHARACTER*180): up to 180 characters
c
c	2	FNAME (CHARACTER*10): name of file to be created with
c			'.dens' appended
c
c			[e.g. 'Hexadiene.dens']
c
c	3	N, IWR, VHAR
c
c		N 	= no. of DoF's
c		IWR	= 0:  Uses exact state counts
c			     (energy grain = Egrain1)
c			= 1:  Uses Whitten-Rabinovitch state densities
c               VHAR    = 'HAR': for vibrational frequencies input as harmonic freqs.
c                       = 'OBS': for vibrational frequencies input as 0-1 observed freqs.
c
c	3	Egrain1, Imax1, Isize, Emax2
c
c		Egrain1	= energy grain in cm-1
c		Imax1	= number of array elements in first segment of
c				double array
c		Isize	= total size of double array
c		Emax2	= maximum energy (cm-1) for calculation
c
c	4..N+3	MODE(I), IDOF(I), WE(I), ANH(I), NG(I)
c
c		MODE	= index number for a degree of freedom (dof)
c		IDOF	= type of dof
c			vib = harmonic or Morse Oscillator vibration
c                       box = quantized particle-in-a-box vibration
c                       rot = classical rotation (for small B)
c			qro = quantized rotation (for large B)
c			kro = quantized 1-dim. K-rotor
c			hra = quantized hindered rotor (extended Troe method) moment, vib
c			hrb = quantized hindered rotor (extended Troe method) vib, barrier
c			hrc = quantized hindered rotor (extended Troe method) moment, barrier
c                            [Barker & Shovlin, Chem. Phys. Letters, 383, 203-207 (2004)]
c                       trn = classical translation
c		WE	= vibration frequency (cm-1) if 'vib' or 'box'
c			= small vibration frequency (cm-1) if 'hra' or 'hrc'
c			= moment of inertia (amu ang^2) if 'rot' or 'qro' 
c                       = Mass of A (amu) for 'trn' (translation)
c		anh	= anharmonicity (cm-1) if 'vib'
c			= reduced moment of inertia (amu ang^2) if 'hra' or 'hrb'
c			= rotor symmetry if 'rot' or 'qro'
c			= Hindered barrier height (cm-1) if 'hrb', 'hrc'
c                       = Mass of B (amu) for 'trn' (translation)
c		ng	= multiplicity if 'vib' or 'box'
c			= rotor dimension if 'rot' or 'qro'
c                       = J (total ang. momentum quantum number) if 'kro'
c                       = ignored if 'trn' (translation)
c			= hindered rotor pot. energy foldedness if 'hra', 'hrb', 'hrc'
c                              [ng < 0  IF UNSYMMETRICAL HINDERED ROTOR]
c            	IF ng < 0 for unsymmetrical hindered rotor, then add a new line containing:
c	        	NSIG = hindered rotor symmetry number if 'hra', 'hrb', 'hrc  
c
c	N+....	BLANK line
c
c
c	 GENERATES 2 OUTPUT FILES:
c	    densum.out		Disk file containing easily read
c				complete output
c	    (FNAME).dens	Disk file with format appropriate for
c				input into MultiWell
c
c
      INCLUDE 'declare.inc'
      DOUBLE PRECISION WOBS, E
      INTEGER lenstr       !Added JP 10/03
      CHARACTER TITLE*180 , FNAME*10, VHAR*3, OBS*3, HAR*3, Arg*10
      CHARACTER bestImaxTXT*6
      CHARACTER readline*100, filename*20
      PARAMETER ( OBS='OBS' , HAR='HAR' )
      INTEGER bestImax(6)
      CHARACTER AVERSION*6, ADATE*12, cut*46
      PARAMETER ( AVERSION='2008.2', ADATE='MAR 2008' )
      PARAMETER (cut='**************INPUT DATA SUMMARY**************')
      EXTERNAL MORLEV , STERAB , GAM , WRAB , WRDEN , ALNGAM , BOXLEV
 
      SAVE 


      call GETARG(1,Arg)
      Arg=Arg(1:lnblnk(Arg))
      IF(Arg.eq."-batch".or.Arg.eq."-BATCH".or.Arg.eq."-Batch") THEN
       Arg="BATCH"
       OPEN(unit=1,err=40,file='densum.batch',status='old')
       READ(1,*) Egrain1, Imax1, Isize, Emax2
       GOTO 41
40     PAUSE "densum.batch not found"
       STOP
41    ENDIF
 
      DO 
       IF(Arg.eq."BATCH") THEN
       READ(1,'(A100)',END=10) readline
       filename=readline(1:lnblnk(readline))
       IF(readline(1:lnblnk(readline)).eq.'') goto 450
       OPEN(unit=5,file=filename,err=50,status='old')  
       GOTO 51
50     WRITE(*,*) 
       WRITE(*,*) "File ",filename(1:lnblnk(filename))," not found"
       WRITE(*,*) 
       GOTO 450

51     OPEN(unit=2,file='densum.dat',status='unknown')

       DO i=1,3
        READ(5,'(A100)') readline
        WRITE(2,*) readline(1:lnblnk(readline))
       ENDDO
       READ(5,*)
       WRITE(2,*) Egrain1, Imax1, Isize, Emax2
       DO 
        READ(5,'(A100)',END=20) readline
        WRITE(2,*) readline(1:lnblnk(readline))
       ENDDO
20    CLOSE(5)
      REWIND(2)
       ELSE
      OPEN (UNIT=2,STATUS='OLD',FILE='densum.dat')              ! Data file 
      ENDIF

      OPEN (UNIT=3,STATUS='UNKNOWN',FILE='densum.out')  ! Full output
 
      WRITE (3,99016) AVERSION , ADATE ,  AVERSION , ADATE
      READ (2,99017) TITLE
      WRITE (3,99017) TITLE
      READ (2,*) FNAME
      WRITE (3,99023) FNAME
      OPEN(UNIT=4,STATUS='UNKNOWN',FILE=FNAME(1:lenstr(fname))//'.dens')
                                                                ! Succinct output for MultiWell input
      WRITE (4,99030) cut                                       ! Start of data summary block in ____.dens file
      WRITE (4,99016) AVERSION , ADATE ,  AVERSION , ADATE


c
c  VHAR  = 'HAR': for vibrational frequencies input as harmonic freqs.
c        = 'OBS': for vibrational frequencies input as 0-1 observed freqs.
c
      READ (2,*) N , IWR , VHAR       ! N=no. of DoF;IWR=0,1 for Stein/Rab or Whitten/Rab

      IF(Arg.eq."BATCH") THEN
       READ (2,*) 
      ELSE
       READ (2,*) Egrain1 , imax1 , Isize , Emax2
      ENDIF
 
      IF (Emax2/Egrain1 .GT. NMAX) PAUSE '****Grain Size Too Small****'

      Emax1 = Egrain1*(imax1-1)
      Egrain2 = Emax2/(Isize-imax1-1)
      imax2 = Isize - imax1
 
      JMAX = 1 + INT(Emax2/Egrain1)
      JMAX = MIN(JMAX,NMAX)
 
      WRITE (3,99008)
      WRITE (4,99008)
 
      Viblo = 10000.
      SS = 0.0d+00 
      SUM2 = 0.0d+00 
      ALNSUM = 0.0d+00 
      NV = 0 
      NROTS = 0 
      NZ = 0 
      ZPE = 0.0d+00 
      DO 100 I = 1 , N
         READ (2,*) MODE(I) , IDOF(I) , WE(I) , ANH(I) , NG(I)
 
         IF ( IDOF(I).EQ.VIB ) THEN                                   ! Vibration: Evib = WE(v+1/2) + ANH*(v+1/2)^2
            Viblo = MIN(Viblo,WE(I))         ! lowest vib frequency
            IF ( VHAR .EQ. HAR ) THEN
              WOBS = WE(I)+2.*ANH(I)         ! WOBS = observed freq
            ELSEIF ( VHAR .EQ. OBS ) THEN
              WOBS = WE(I)
              WE(I)= WE(I)-2.*ANH(I)         ! Convert WE to harmonic frequency
            ENDIF
            WRITE (3,99002) MODE(I) , WOBS , WE(I) , ANH(I) , NG(I)
            WRITE (4,99002) MODE(I) , WOBS , WE(I) , ANH(I) , NG(I)
            NV = NV + NG(I) 
            zzpe(I) = 0.5d+00*WE(I) + 0.25d+00*ANH(I)
            SS = SS + NG(I)*zzpe(I) 
            SUM2 = SUM2 + NG(I)*4.0*zzpe(I)**2 
            ALNSUM = ALNSUM + NG(I)*LOG(2.0*zzpe(I)) 
         ELSEIF ( IDOF(I).EQ.BOX ) THEN                               ! Particle-in-a-Box Vibration: Evib = WE*v^2
            Viblo = MIN(Viblo,WE(I))         ! lowest vib frequency
            IF ( VHAR .EQ. HAR ) THEN
              WOBS = 3.d+00*WE(I)            ! WOBS = observed freq
            ELSEIF ( VHAR .EQ. OBS ) THEN
              WOBS = WE(I)
              WE(I)= WE(I)/3.0d+00           ! Convert WE to frequency
            ENDIF
            WRITE (3,99022) MODE(I) , WOBS , WE(I) , NG(I)
            WRITE (4,99022) MODE(I) , WOBS , WE(I) , NG(I)
            NV = NV + NG(I)                                
            zzpe(I) = WOBS/2.d+00 
            SS = SS + NG(I)*zzpe(I)              
            SUM2 = SUM2 + NG(I)*9.d+00*zzpe(I)**2 
            ALNSUM = ALNSUM + NG(I)*LOG(3.d+00*zzpe(I)) 
         ELSEIF ( IDOF(I).EQ.KRO ) THEN                               ! 1-dim. K-rotor
            AMOM(I) = WE(I)                     ! moment of inertia
            B(I) = 16.85763D+00/AMOM(I)         ! rotational constant (cm-1)
            WRITE (3,99051) MODE(I) , WE(I) , ANH(I) , NG(I) , B(I)
            WRITE (4,99051) MODE(I) , WE(I) , ANH(I) , NG(I) , B(I)
            NROTS = NROTS + 1 
            IF ( ANH(I).LE.0 ) THEN
               WRITE (3,99006)
               WRITE (4,99006)
               PAUSE
            ENDIF
         ELSEIF ( IDOF(I).EQ.QRO ) THEN                               ! Quantized rotor
            AMOM(I) = WE(I)                     ! moment of inertia
            B(I) = 16.85763D+00/AMOM(I)         ! rotational constant (cm-1)
            WRITE (3,99005) MODE(I) , WE(I) , ANH(I) , NG(I) , B(I)
            WRITE (4,99005) MODE(I) , WE(I) , ANH(I) , NG(I) , B(I)
            NROTS = NROTS + 1 
            IF ( ANH(I).LE.0 ) THEN
               WRITE (3,99006)
               WRITE (4,99006)
               PAUSE
            ENDIF
         ELSEIF ( IDOF(I).EQ.ROT ) THEN                               ! Classical rotor
            AMOM(I) = WE(I)                     ! moment of inertia
            B(I) = 16.85763D+00/AMOM(I)         ! rotational constant (cm-1)
            WRITE (3,99003) MODE(I) , WE(I) , ANH(I) , NG(I) , B(I)
            WRITE (4,99003) MODE(I) , WE(I) , ANH(I) , NG(I) , B(I)
            NROTS = NROTS + 1 
            IF ( ANH(I).LE.0 ) THEN
               WRITE (3,99006)
               WRITE (4,99006)
               PAUSE
            ENDIF
         ELSEIF ( IDOF(I).EQ.HRA ) THEN         ! INPUT MOMENT & VIB FREQ   Hindered rotor
            IF ( NG(I) .LT. 0) THEN
                READ(2,*) NSIG(I)
                NG(I) = -NG(I)
              ELSE
                NSIG(I) = NG(I)
            ENDIF
            W(I) = WE(I)                        ! small vibration frequency
            Viblo = MIN(Viblo,W(I))             ! lowest vib frequency
            AMOM(I) = ANH(I)                    ! moment of inertia
            B(I) = 16.85763D+00/AMOM(I)         ! rotational constant (cm-1)
            VV(I) = ((W(I)/NG(I))**2)/B(I)      ! hindrance barrier (cm-1)
            WRITE (3,99004) MODE(I) , W(I) , AMOM(I) , NG(I) , NSIG(I) , 
     &             B(I) , VV(I)                         ! Hindered rotor (extended Troe method)
            WRITE (4,99004) MODE(I) , W(I) , AMOM(I) , NG(I) , NSIG(I) , 
     &             B(I) , VV(I)                         ! Hindered rotor (extended Troe method)
            NV = NV + 1                                 
            zzpe(I) = W(I)/2.0d+00  
            SS = SS + zzpe(I) 
            SUM2 = SUM2 + 4.0*zzpe(I)**2 
            ALNSUM = ALNSUM + LOG(2.0*zzpe(I)) 
            IF ( ANH(I).LE.0 .OR. NG(I).EQ.0 ) THEN
               WRITE (3,99007)
               WRITE (4,99007)
               PAUSE
            ENDIF
         ELSEIF ( IDOF(I).EQ.HRB ) THEN         ! INPUT VIB FREQ & BARRIER   Hindered rotor
            IF ( NG(I) .LT. 0) THEN
                READ(2,*) NSIG(I)
                NG(I) = -NG(I)
              ELSE
                NSIG(I) = NG(I)
            ENDIF
            W(I) = WE(I)                        ! small vibration frequency
            Viblo = MIN(Viblo,W(I))             ! lowest vib frequency
            VV(I) = ANH(I)                      ! hindrance barrier (cm-1)
            IF (VV(I) .LT. 1.0d-05) PAUSE
     &        'Rotation barrier too small. Hit RETURN to terminate' 
            B(I) = ((W(I)/NG(I))**2)/VV(I)      ! rotational constant (cm-1)
            AMOM(I) = 16.85763D+00/B(I)         ! moment of inertia (amu*ang^2)
            WRITE (3,99004) MODE(I) , W(I) , AMOM(I) , NG(I) , NSIG(I) ,
     &             B(I) , VV(I)                         ! Hindered rotor (extended Troe method)
            WRITE (4,99004) MODE(I) , W(I) , AMOM(I) , NG(I) , NSIG(I) ,
     &             B(I) , VV(I)                         ! Hindered rotor (extended Troe method)
            NV = NV + 1                                  
            zzpe(I) = W(I)/2.0d+00   
            SS = SS + zzpe(I)  
            SUM2 = SUM2 + 4.0*zzpe(I)**2  
            ALNSUM = ALNSUM + LOG(2.0*zzpe(I))  
            IF ( ANH(I).LE.0 .OR. NG(I).LE.0 ) THEN
               WRITE (3,99007)
               WRITE (4,99007)
               PAUSE
            ENDIF
         ELSEIF ( IDOF(I).EQ.HRC ) THEN         ! INPUT MOMENT & BARRIER   Hindered rotor
            IF ( NG(I) .LT. 0) THEN
                READ(2,*) NSIG(I)
                NG(I) = -NG(I)
              ELSE
                NSIG(I) = NG(I)
            ENDIF
            AMOM(I) = WE(I)                     ! moment of inertia (amu*ang^2)
            B(I) = 16.85763D+00/AMOM(I)         ! rotational constant (cm-1)
            VV(I) = ANH(I)                      ! hindrance barrier (cm-1)
            W(I) = NG(I)*SQRT(B(I)*VV(I))       ! small vibration frequency
            Viblo = MIN(Viblo,W(I))             ! lowest vib frequency
            WRITE (3,99004) MODE(I) , W(I) , AMOM(I) , NG(I) , NSIG(I) ,
     &             B(I) , VV(I)                         ! Hindered rotor (extended Troe method)
            WRITE (4,99004) MODE(I) , W(I) , AMOM(I) , NG(I) , NSIG(I) ,
     &             B(I) , VV(I)                         ! Hindered rotor (extended Troe method)
            NV = NV + 1                                  
            zzpe(I) = W(I)/2.0d+00   
            SS = SS + zzpe(I)  
            SUM2 = SUM2 + 4.0*zzpe(I)**2  
            ALNSUM = ALNSUM + LOG(2.0*zzpe(I))  
            IF ( ANH(I).LE.0 .OR. NG(I).EQ.0 ) THEN
               WRITE (3,99007)
               WRITE (4,99007)
               PAUSE
            ENDIF
         ELSEIF ( IDOF(I) .EQ. TRN ) THEN                 ! RELATIVE TRANSLATION
            AMOM(I) = WE(I)*ANH(I)/( WE(I) + ANH(I) )     ! reduced mass (amu)
            WRITE (3,99021) MODE(I) , WE(I) , ANH(I), AMOM(I)
            WRITE (4,99021) MODE(I) , WE(I) , ANH(I), AMOM(I)
            IF ( NG(I).LE.0 .OR. NG(I).GT.3 ) THEN
               WRITE (3,99022)
               PAUSE
            ENDIF

         ELSE
          write( 3,*) IDOF(I)
          write( 4,*) IDOF(I)
          PAUSE 'FATAL ERROR: unrecognized dof-type in densum.dat ***  '

         ENDIF
 
 100  CONTINUE
 
      WRITE (4,99030) cut       ! End of data summary block in ____.dens file
      
      
      ZPE = SS 
      SS = 2.0d+00*SS 
      BETA = (NV-1)*(NV+0.5*NROTS)*SUM2/(NV*SS**2) 
      AVENUE = EXP(ALNSUM/NV) 
C
C     CALCULATE SUMS AND DENSITIES
C
      WRITE (*,99019)
      IF ( IWR.EQ.0 ) THEN              ! Exact counts
         CALL STERAB(N,JMAX,Egrain1)
      ELSEIF ( IWR.EQ.1 ) THEN          ! Whitten-Rabinovitch approximation
         CALL WRAB(NV,NROTS,ZPE,BETA,AVENUE,JMAX,Egrain1,SUM,DENS)
      ENDIF
c
c
c      Check density
c
      call chkdens(Egrain1,Imax1,Isize,Emax2,bestImax)
c
c
c	Write out results
c
c
c      Succinct output for MultiWell input
 
      WRITE (4,*) FNAME(1:lenstr(fname))
      IF(Imax1.lt.bestImax(5)) THEN
       WRITE (4,'(A15,A49,I6)') TITLE(1:lnblnk(TITLE)),
     & "  --  WARNING. Miminum suggested value for Imax1:",bestImax(5)
      ELSE
       WRITE (4,'(A50)') TITLE
      ENDIF
      WRITE (4,99001) Egrain1 , imax1 , Emax2 , Isize , Viblo
 
      IF ( IWR.EQ.0 ) THEN
         WRITE (3,99012) Egrain1
                                ! Exact Counts
      ELSE
         WRITE (3,99013)        ! Whitten-Rabinovitch
      ENDIF
 
      WRITE (3,99020) NV , NROTS , ZPE , AVENUE , BETA

      x=0
      WRITE(3,*) " Density fluctuations %       Imax1       E(cm-1)"
      DO i=1,5
         if (bestImax(i).ne.INT(Emax2/Egrain1)) then
          E=(bestImax(i)-1)*Egrain1
         else
          E=Emax2
         endif
!      IF(bestImax(i).ne.0) THEN
        IF(Imax1.ge.bestImax(i).AND.x.lt.1) THEN
         x=x+1
         WRITE(3,'(A10,I2,A18,I6,A6,F8.1,A12)') "          ",i,
     &"%                 ", bestImax(i), "      ", E, "  <- Current"
          ELSE
           IF(bestImax(i).eq.INT(Emax2/Egrain1)) then
           WRITE(3,'(A10,I2,A18,I6,A6,F8.1,A12)') "          ",i,
     &"%                >", bestImax(i), "     >", E
           ELSE
           WRITE(3,'(A10,I2,A18,I6,A6,F8.1,A12)') "          ",i,
     &"%                 ", bestImax(i), "      ", E
           ENDIF 
        ENDIF
!      ENDIF
      ENDDO
       WRITE(3,*)
      IF(Imax1.lt.bestImax(5)) THEN
       WRITE (3,*) "WARNING: the current density fluctuation at Imax1 is
     & larger the 5%."
       WRITE (3,'(A35,I6)') " Miminum suggested value for Imax1:",
     & bestImax(5)
       WRITE(3,*)
       DO i=1,5
        IF(bestImax(i).eq.INT(Emax2/Egrain1).AND.
     &   bestImax(i+1).le.INT(Emax2/Egrain1)) then 
       WRITE(3,'(A57,I2,A2)')" WARNING: the density fluctuation at Emax2
     & is larger than",i," %."
         WRITE (3,*) "Increase Emax2"
        ENDIF
       ENDDO
       WRITE(3,*)
       WRITE(3,*)
      ENDIF
 
      WRITE (3,99011)
      WRITE (4,99010)
 
      DO 200 i = 1 , imax1
         E = (i-1)*Egrain1
         WRITE (4,99014) i , E , DENS(i) , SUM(i)
 200  CONTINUE
 
      DO 300 i = imax1 + 1 , Isize
         E = (i-imax1-1)*Egrain2
         j = INT(E/Egrain1) + 1
         WRITE (4,99014) i , E , DENS(j) , SUM(j)
 300  CONTINUE
 
      DO 400 i = 1 , JMAX
         E = (i-1)*Egrain1
         WRITE (3,99015) i , E , DENS(i) , SUM(i)
 400  CONTINUE
 
99001 FORMAT (1x,f10.1,1x,I10,1x,f10.1,1x,I10,1x,f10.1)
99002 FORMAT (I5,2X,'Vibrator',2x,'Freq(0-1)=',F8.2,2x,
     &        'Freq(har)=',F8.2,2x,'Anh(cm-1)=',F8.2,2X,
     &        'g =',I2)
99022 FORMAT (I5,2X,'P-in-Box',2x,'Freq(0-1)=',F8.2,2x,
     &        'Freq.Param.=',F8.2,2x,'g =',I2)
99003 FORMAT (I5,2X,'Clas.Rot',2x,'Moment   =',F8.2,2x,'Symm =',F4.0,2x,
     &        ' dim =',I2,2x,'B =',F8.4,' cm-1')
99004 FORMAT (I5,2X,'Hind.Rot',2x,'Freq(har)=',F8.2,2x,'Mom=',F8.3,2x,
     &       'fold=',I2,2x,'symm=',I2,2x,'B=',F8.4,' cm-1',2x,
     &        'Uo=',F7.1,' cm-1')
99005 FORMAT (I5,2X,'Quan.Rot',2x,'Moment   =',F8.2,2x,'Symm =',F4.0,2x,
     &        ' dim =',I2,2x,'B =',F8.4,' cm-1')
99051 FORMAT (I5,2X,'K-rotor ',2x,'Moment   =',F8.2,2x,'Symm =',F4.0,2x,
     &        ' J   =',I2,2x,'B =',F8.4,' cm-1')
99006 FORMAT (//'Rotor symmetry number must be greater than zero')
99007 FORMAT (//'Hindered rotor parameters incomplete')
99008 FORMAT (//'Degrees of Freedom'/)
99009 FORMAT (/'  No.  Freq(cm-1)  ANH(cm-1)      Degeneracy'/)
99010 FORMAT ('       No.     (cm-1)   Density   Sum')
99011 FORMAT ('       No.     (cm-1)   Density     Sum')
99012 FORMAT (//'Stein-Rabinovitch Method (grain =',F6.1,' cm-1)'//)
99013 FORMAT (//'Whitten-Rabinovitch Method'//)
99014 FORMAT (i10,1x,f10.1,2(1x,1pe10.3))
99015 FORMAT (i10,1x,f10.1,2(1x,1pe12.5))
99016 FORMAT (
     &'%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     &%%%%%%%%%%%%%'//8x,
     &'                                John R. Barker'/8x,
     &'        DenSum-',A6,'           University of Michigan'/8x,
     &'                                Ann Arbor, MI 48109-2143'/8x,
     &'        ',A8,'                jrbarker@umich.edu'/8x,
     &'                                (734) 763 6239'//8x,
     &'      http://aoss.engin.umich.edu/multiwell/'//,
     &'%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     &%%%%%%%%%%%%%'//8x,
     &'Citation:'//8x,
     &'a) MultiWell-',A6,' Software, ',A8,', designed and '/8x,
     &'   maintained by J. R. Barker with contributions from N. F.'/8x,
     &'   Ortiz, J. M. Preses, L. L. Lohr, A. Maranzana, and'/8x,
     &'   P. J. Stimac; University of Michigan, Ann Arbor, MI; '/8x,
     &'   http://aoss.engin.umich.edu/multiwell/.'//8x,
     &'b) J. R. Barker, Int. J. Chem. Kinetics, 33, 232-45 (2001).'//
     &'%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     &%%%%%%%%%%%%%'/)
99017 FORMAT (A180)
99018 FORMAT (A10)
99019 FORMAT (/'Calculating Densities')
99020 FORMAT (/'WHITTEN-RABINOVITCH PARAMETERS'/'   Vibrations:  ',I10/
     &        '   Rotations:   ',I10,/, '   Zero Point E:',f12.3,/
     &        ' Geo. Mean Freq:',f10.3,/'           Beta:',f10.3,//)
99021 FORMAT (I5,2X,'Translat',2x,'MolWt(A) =',F8.2,2x,'MolWt(B) =',
     &           F8.2,2x,'RedMass =',F8.2,1x,'g/mol')
99023 FORMAT (/A10)
99030 FORMAT (A46)

      IF(Arg.ne."BATCH") GOTO 500
     
      CLOSE(2)
450   ENDDO

10    CLOSE(1)

500   END
