**==book1.spg  processed by SPAG 5.11R  at 20:12 on 26 Mar 2001
      SUBROUTINE BOOK1(Mol,E,Temp,IP,Time,Delt,Igo)
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c
c MultiWell: a code for chemical kinetics calculations.
c Copyright (C) 2001 John R. Barker
c
c John R. Barker
c jrbarker@umich.edu
c University of Michigan
c Ann Arbor, MI 48109-2143
c (734) 763 6239
c
c This program is free software; you can redistribute it and/or
c modify it under the terms of the GNU General Public License (version 2)
c as published by the Free Software Foundation.
c
c This program is distributed in the hope that it will be useful,
c but WITHOUT ANY WARRANTY; without even the implied warranty of
c MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
c GNU General Public License for more details.
c
c See the 'ReadMe' file for a copy of the GNU General Public License,
c or contact:
c
c Free Software Foundation, Inc.
c 59 Temple Place - Suite 330
c Boston, MA 02111-1307, USA.
c
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c	Bookkeeping routine, works in concert with Subroutine STEPPER
c
c	Mol	= index of molecule at time=Time
c	E	= vibrational energy (relative to ZPE of Mol) at t=Time
c	Temp	= translational temperature
c	IP	= index of selected process = rxn channel number,
c			or Nchan+1 if collision
c	Time	= time
c	Delt	= time step
c	Igo	= flag which signals the following:
c		= 0	stop stepping for this trial
c		= 1	continue stepping for this trial
c
c***********************************************************************
c
c Date   Version  Revisions
c
c 08/02  v1.2.3  -Bug Fix: in subroutine book1.f, fixed bug that gave 
c                 erroneously large yields wen the time scale was much shorter
c                 than the inverse of the sum of the rates (k(E) + collision
c                 frequency).
c 05/02  v1.2.2  -Revised averaging of kuni so that only one sample per time bin per
c                 trial is included in the average. Previous algorithm resulted in
c                 over-weighting faster k(E)'s and gave erroneously high average kuni
c                 reported in multiwell.out.
c
c***********************************************************************

      IMPLICIT NONE
      INCLUDE 'declare1.inc'
      INCLUDE 'declare2.inc'
      INTEGER Mol , IP , Igo , ifin , i , Last , N
      INTEGER ifind , Dlast , k , istart
      DOUBLE PRECISION E , Temp , Time , Delt , COLSTEP , Step , 
     &                 DistStep
      SAVE 

      DistStep = Emax2/(Ndist-1)                ! Energy step for binned distributions
      N = 1 + E/DistStep                        ! Bin energy index for binned distributions
      IF ( N.GT.Ndist ) N = Ndist
c
c	First, record the current step
c
      IF ( Time.EQ.0.0D+00 ) THEN               ! First step of a trial
         Last = 1                               ! index of final bin for last step
         Dlast = 1                              ! index of final bin for vib distribution
         Num(Mol,1) = Num(Mol,1) + 1.d+00       ! Number of times 1st time bin accessed (for averages)
         Mum(Mol,1) = Mum(Mol,1) + 1.d+00       ! Number of times 1st time bin accessed (for EDIST)
         EMol(Mol,1) = EMol(Mol,1) + E          ! For calculating average vibrational energy
         EDIST(Mol,N,1) = EDIST(Mol,N,1) + 1.d+00   ! For calculating vibrational distribution
         Nuni(Mol,1) = Nuni(Mol,1) + 1.0D+00
         DO 15 k = 1 , Nchan(Mol)                   ! Rab(k)= k(E) for kth channel calculated by STEPPER
            kuni(Mol,k,1) = Rab(k) + kuni(Mol,k,1)  ! average rate constant
 15      CONTINUE
      ENDIF

      ifin = 1 + ((Time+Delt)/Tlim)*(Ntime-1)   ! index of final time-bin for this step
      IF ( ifin.GT.Ntime ) THEN
         ifin = Ntime
         Igo = 0                                ! Stop stepping
      ENDIF
 
      ifind = 1 + (Time+Delt)*(Mtime-1)/Tlim    ! Vib distribution final time-bin index
      IF ( ifind.GT.Mtime ) ifind = Mtime
 

      IF ( Nchan(Mol).GT.0 .AND. ifin.GT.Last ) THEN   ! Sample at end of each time bin
         IF ( ifin.EQ.Last ) THEN
            istart = Last
           ELSE
            istart = Last + 1
         ENDIF
         DO 250 i = istart , MIN(ifin,Ntime)
            Nuni(Mol,i) = Nuni(Mol,i) + 1.0D+00
            DO 150 k = 1 , Nchan(Mol)                  ! Rab(k)= k(E) for kth channel calculated by STEPPER [includes IVR effects]
               kuni(Mol,k,i) = Rab(k) + kuni(Mol,k,i)  ! average rate constant [includes IVR effects]
 150        CONTINUE
 250     CONTINUE
      ENDIF
 
      IF ( ifin.GT.Last ) THEN                  ! snapshot at end of each time interval
         DO 50 i = Last + 1 , MIN(ifin,Ntime)
            Num(Mol,i) = Num(Mol,i) + 1.d+00    ! Number of times ith bin accessed
            EMol(Mol,i) = EMol(Mol,i) + E       ! Average vibrational energy
 50      CONTINUE
         Last = ifin
      ENDIF

      IF ( ifind.GT.Dlast ) THEN                ! snapshot at end of each time interval
         DO 100 i = Dlast + 1 , MIN(ifind,Mtime)
            Mum(Mol,i) = Mum(Mol,i) + 1.d+00    ! Number of times ith time bin accessed
            EDIST(Mol,N,i) = EDIST(Mol,N,i) + 1.d+00 ! vibrational distribution
 100     CONTINUE
         Dlast = ifind
      ENDIF
c
c	Now make changes
c
 
      Time = Time + Delt
 
      IF ( Igo.EQ.0 ) THEN                              ! Stop stepping
         RETURN
      ELSEIF ( IP.EQ.(1+Nchan(Mol)) ) THEN              ! COLLISION
         Step = COLSTEP(Mol,E,Temp)                     ! Collision step

c         WRITE (21,*) E           !  <-------------------------------------- FOR STEP-SIZE DISTRIBUTION

         E = E + Step                                   ! Energy after collision
      ELSE                                              ! REACTION
         IF ( Jto(Mol,IP).LE.NWells ) E = E + HMol(Mol)
     &        - HMol(Jto(Mol,IP))                       ! Vib energy of new molecule
         Mol = Jto(Mol,IP)                              ! New molecule index
      ENDIF
 
      IF ( Mol.GT.NWells .AND. Last.LT.Ntime ) THEN     ! If irreversible product
         Igo = 0                                        ! Stop stepping
         DO 200 i = Last + 1 , Ntime
            Num(Mol,i) = Num(Mol,i) + 1.d+00            ! Number of times ith bin accessed
 200     CONTINUE
      ENDIF
 
      RETURN
      END
