**==pdown.spg  processed by SPAG 5.11R  at 20:12 on 26 Mar 2001
 
      DOUBLE PRECISION FUNCTION PDOWN(E,EE,Mol,TEMPI,Hs)
 
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
c
c MultiWell: a code for chemical kinetics calculations.
c Copyright (C) 2005 John R. Barker
c
c John R. Barker
c jrbarker@umich.edu
c University of Michigan
c Ann Arbor, MI 48109-2143
c (734) 763 6239
c
c This program is free software; you can redistribute it and/or
c modify it under the terms of the GNU General Public License (version 2)
c as published by the Free Software Foundation.
c
c This program is distributed in the hope that it will be useful,
c but WITHOUT ANY WARRANTY; without even the implied warranty of
c MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
c GNU General Public License for more details.
c
c See the 'ReadMe' file for a copy of the GNU General Public License,
c or contact:
c
c Free Software Foundation, Inc.
c 59 Temple Place - Suite 330
c Boston, MA 02111-1307, USA.
c
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c
c      REVISIONS
c
c      12/2004  Added two new energy transfer models (#12 and #13)
c      12/2004  General overhaul to improve speed and accuracy, especially at 
c               low energies.
c
c
c%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c
c	PDOWN	= step-size probability density distribution, not normalized,
c		for DOWN-steps:  E > EE
c	E	= initial energy
c	EE	= final energy
c	Mol	= index number for a molecule
c	TEMPI	= translational temperature
c	Hs	= characteristic 'average' step size corresponding to PDOWN;
c		used in SUBROUTINEs COLNORM and COLSTEP to determine integration
c		step-sizes.
c
c	ITYPE (stored in a COMMON) is a flag used to designate collision model:
c
c	ITYPE = 1  for Biexponential Model
c	ITYPE = 2  for Density-weighted Biexponential Model
c       ITYPE = 3  for Off-set Gaussian with constant offset and E-dependent width
c	ITYPE = 4  for Biexponential Model with energy-dependent fraction
c	ITYPE = 5  for Generalized Gaussian with energy-dependent exponent
c	ITYPE = 6  for Generalized Gaussian plus Exponential term
c	ITYPE = 7  for Weibull Model
c	ITYPE = 8  for Lorentzian Step-Ladder Model
c	ITYPE = 9  for Exponential+Elastic Model
c	ITYPE = 10 for Klaus Luther's empirical function
c	ITYPE = 11 for Triplet state empirical function
c	ITYPE = 12 for Exponential Model with Alpha(E)=linear + exponential
c	ITYPE = 13 for Exponential Model with alpha(E) switching function
c
      IMPLICIT NONE
 
      DOUBLE PRECISION DENVR , TEMPI
      INCLUDE 'declare1.inc'
 
      INTEGER Mol
 
      DOUBLE PRECISION B , DENE , E , EE , Hs
 
      DOUBLE PRECISION TERM1 , TERM11 , TERM2 , TERM22 , ALPHA , 
     &                 ALPHA1 , ALPHA2 , EN , Fractt , A , BET , BETA , 
     &                 X , ARG , ARG1 , ARG2 , WIDTH , F , TT , Rob_3
 
      SAVE 
 
      IF ( E.LT.-0.9 ) THEN     ! Indicates that we just want the title lines
 
         LI(Mol,1) = '  '
         LI(Mol,2) = '  '
         LI(Mol,3) = '  '
         LI(Mol,4) = '  '
         LI(Mol,5) = '  ' 

         IF ( ITYPE(Mol).NE.1 ) THEN
            IF ( ITYPE(Mol).EQ.2 ) THEN
 
               LI(Mol,1) = ' Density-weighted Biexponential Model'
 
               LI(Mol,2) = 
     &                   '  Alpha1 = C(1) + [E*C(2) + E*E*C(3)]*T**C(8)'
               LI(Mol,3) = 
     &                   '  Alpha2 = C(5) + [E*C(6) + E*E*C(7)]*T**C(8)'
               LI(Mol,4) = 
     &' Pdown = rho*((1-C(4))*EXP(-(E-EE)/Alpha1) + C(4)*EXP(-(E-EE)/Alp
     &ha2))'
c        1         2         3         4         5         6         7         8
               RETURN
            ELSEIF ( ITYPE(Mol).EQ.3 ) THEN
 
               LI(Mol,1) = 
     &                ' Constant off-set, variable width Gaussian Model'
 
               LI(Mol,2) = 
     &                   '  Alpha1 = C(1) + [E*C(2) + E*E*C(3)]*T**C(8)'
               LI(Mol,3) = 
     &              '  C(4) = constant off-set, Alpha1 is the std. dev.'
               LI(Mol,4) = ' Pdown = EXP(-(0.5*(E-EE-C(4))/Alpha1)**2)'
c        1         2         3         4         5         6         7         8
               RETURN
            ELSEIF ( ITYPE(Mol).EQ.4 ) THEN
 
               LI(Mol,1) = 
     &             ' Biexponential Model with Energy-Dependent Fraction'
 
               LI(Mol,2) = '  Alpha1 = C(1) + [E*C(2) + E*E*C(3)]'
               LI(Mol,3) = '  Alpha2 = C(5) + [E*C(6) + E*E*C(7)]'
               LI(Mol,4) = 
     &' Pdown = (1-[C(4)+E*C(8)])*EXP(-(E-EE)/Alpha1) + [C(4)+E*C(8)]*EX
     &P(-(E-EE)/Alpha2)'
c        1         2         3         4         5         6         7         8
               RETURN
            ELSEIF ( ITYPE(Mol).EQ.5 ) THEN
 
               LI(Mol,1) = 
     &            'Generalized Gaussian Model with E-Dependent Exponent'
 
               LI(Mol,2) = '  Alpha = C(1) + [E*C(2) + E*E*C(3)]'
               LI(Mol,3) = '  exponent = C(5) + [E*C(6) + E*E*C(7)]'
               LI(Mol,4) = ' Pdown = EXP(-[(E-EE)/Alpha]**Exponent)'
c        1         2         3         4         5         6         7         8
               RETURN
            ELSEIF ( ITYPE(Mol).EQ.6 ) THEN
 
               LI(Mol,1) = ' Generalized Gaussian + Exponential'
 
               LI(Mol,2) = 
     &'  Alpha1   = C(1) + [E*C(2) + E*E*C(3)]    Alpha2 = C(7)+ E*C(8)'
               LI(Mol,3) = '  Exponent = C(4) + E*C(5)'
               LI(Mol,4) = '  F        = C(6)'
               LI(Mol,5) = 
     &' Pdown     = (1-C(6))*EXP(-[(E-EE)/Alpha1]**Exponent) + C(6)*EXP(
     &-(E-EE)/Alpha2)'
c        1         2         3         4         5         6         7         8
               RETURN
            ELSEIF ( ITYPE(Mol).EQ.7 ) THEN
 
               LI(Mol,1) = ' Weibull Model'
 
               LI(Mol,2) = 
     &                    '  Alpha = {C(1) + [E*C(2) + E*E*C(3)]}**Beta'
               LI(Mol,3) = '  Beta  = C(4) + E*C(5)'
               LI(Mol,4) = 
     &' Pdown  = (Beta/Alpha)*{(E-EE)**(beta-1)}*exp(-((E-EE)/Alpha)**Be
     &ta)'
c        1         2         3         4         5         6         7         8
               RETURN
            ELSEIF ( ITYPE(Mol).EQ.8 ) THEN
 
               LI(Mol,1) = ' Lorentzian Step-Ladder Model'
 
               LI(Mol,2) = '  Alpha = C(1) + [E*C(2) + E*E*C(3)]'
               LI(Mol,3) = '  Width = C(5) + [E*C(6) + E*E*C(7)]'
               LI(Mol,4) = ' Pdown = 1 / [(E-EE-Alpha)^2 + Width^2]'
c        1         2         3         4         5         6         7         8
               RETURN
            ELSEIF ( ITYPE(Mol).EQ.9 ) THEN
 
               LI(Mol,1) = ' Exponential+Elastic Model'
 
               LI(Mol,2) = 
     &                    '  Alpha = C(1) + [E*C(2) + E*E*C(3)]*T**C(8)'
               LI(Mol,3) = 
     &            '      F = C(5) + [(E/C(6))**C(7)]*T**C(8); when E=EE'
               LI(Mol,4) = 
     &              ' Pdown = [F/(F+C(4))]*EXP(-(E-EE)/Alpha) + elastic'
c        1         2         3         4         5         6         7         8
               RETURN
            ELSEIF ( ITYPE(Mol).EQ.10 ) THEN
 
               LI(Mol,1) = ' Klaus Luther s P(EE,E) Empirical Function'
 
               LI(Mol,2) = '  Alpha = C(1) + E*C(2)'
               LI(Mol,3) = '  Beta  = C(3)'
               LI(Mol,4) = ' Pdown = EXP {-[(E-EE)/Alpha]^Beta}'
c        1         2         3         4         5         6         7         8
               RETURN
            ELSEIF ( ITYPE(Mol).EQ.11 ) THEN
 
               LI(Mol,1) = ' Triplet State P(EE,E) Empirical Function'
 
               LI(Mol,2) = 
     &                   '  Alpha = C(1)*{1-exp[-(E/C(2))^C(3)] + C(4)}'
               LI(Mol,3) = '  Pdown = EXP [-(E-EE)/Alpha]'
               LI(Mol,4) = ' '
c        1         2         3         4         5         6         7         8
               RETURN
            ELSEIF ( ITYPE(Mol).EQ.12 ) THEN
 
               LI(Mol,1) = 
     &             'Exponential Model with alpha(E)= Linear+exponential'
 
               LI(Mol,2) = ' Alpha1 = C(1) + E*C(2) + C(3)*exp(-E/C(4))'
               LI(Mol,3) =  ' Pdown = EXP(-(E-EE)/Alpha1)'
c        1         2         3         4         5         6         7         8
               RETURN
            ELSEIF ( ITYPE(Mol).EQ.13 ) THEN
 
               LI(Mol,1) = ' Exponential Model with Switching Function'
 
               LI(Mol,2) = 
     &           '  Alpha1 = C(1) + E*C(2);      Alpha2 = C(3) + E*C(4)'
               LI(Mol,3) = 
     &' Alp = Alpha1 + 0.5*(Alpha2 - Alpha1)*(1. - TANH((C(5)-E)/C(6)))'
               LI(Mol,4) =  ' Pdown = EXP(-(E-EE)/Alp)'
c        1         2         3         4         5         6         7         8
               RETURN
            ENDIF
         ENDIF
 
         LI(Mol,1) = ' Biexponential Model'
 
         LI(Mol,2) = '  Alpha1 = C(1) + [E*C(2) + E*E*C(3)]*T**C(8)'
         LI(Mol,3) = '  Alpha2 = C(5) + [E*C(6) + E*E*C(7)]*T**C(8)'
         LI(Mol,4) = 
     &' Pdown = (1-C(4))*EXP(-(E-EE)/Alpha1) + C(4)*EXP(-(E-EE)/Alpha2)'
c        1         2         3         4         5         6         7         8
         RETURN
 
      ENDIF
 
 
 
      IF ( ITYPE(Mol).NE.1 ) THEN
         IF ( ITYPE(Mol).EQ.2 ) THEN
 
            ALPHA1 = ABS(DC(Mol,1)+(E*(DC(Mol,2)+E*DC(Mol,3)))
     &               *TEMPI**DC(Mol,8))
 
 
 
            ALPHA2 = ABS(DC(Mol,5)+(E*(DC(Mol,6)+E*DC(Mol,7)))
     &               *TEMPI**DC(Mol,8))
 
            IF ( ALPHA1.GT.0.0 ) THEN
               TERM1 = EXP(-ABS(E-EE)/ALPHA1)
               TERM11 = TERM1/ALPHA1
            ELSE
               TERM1 = 0.0D+00
               TERM11 = 0.0D+00
            ENDIF
 
            IF ( ALPHA2.GT.0.0 ) THEN
               TERM2 = EXP(-ABS(E-EE)/ALPHA2)
               TERM22 = TERM2/ALPHA2
            ELSE
               TERM2 = 0.0D+00
               TERM22 = 0.0D+00
            ENDIF
 
            DENE = DENVR(Mol,E)
            PDOWN = DENE*((1.0D00-DC(Mol,4))*TERM1+DC(Mol,4)*TERM2)
            Hs = DENE*((1.0D00-DC(Mol,4))*TERM11+DC(Mol,4)*TERM22)
            Hs = PDOWN/Hs
            IF ( Hs.GT.MAX(ALPHA1,ALPHA2) ) THEN
               Hs = MAX(ALPHA1,ALPHA2)
c            ELSEIF ( Hs.LT.MIN(ALPHA1,ALPHA2) ) THEN
c               Hs = MIN(ALPHA1,ALPHA2)
c               Hs = MAX(Hs,Egrain1)
            ENDIF
 
 
            RETURN
         ELSEIF ( ITYPE(Mol).EQ.3 ) THEN
 
            ALPHA1 = ABS(DC(Mol,1)+(E*(DC(Mol,2)+E*DC(Mol,3)))
     &               *TEMPI**DC(Mol,8))
 
 
 
            IF ( ALPHA1.GT.0.0 ) THEN
               TERM1 = EXP(-(0.5*(E-EE-DC(Mol,4))/ALPHA1)**2)
               TERM11 = -(E-EE-DC(Mol,4))*TERM1/(ALPHA1**2)
            ELSE
               TERM1 = 0.0D+00
               TERM11 = 0.0D+00
            ENDIF
 
            PDOWN = TERM1
            Hs = ABS(TERM1/TERM11)
            IF ( Hs.GT.0.5*ALPHA1 ) Hs = 0.5*ALPHA1
 
            RETURN
         ELSEIF ( ITYPE(Mol).EQ.4 ) THEN
 
            ALPHA1 = ABS(DC(Mol,1)+(E*(DC(Mol,2)+E*DC(Mol,3))))
 
 
            ALPHA2 = ABS(DC(Mol,5)+(E*(DC(Mol,6)+E*DC(Mol,7))))
 
            IF ( ALPHA1.GT.0.0 ) THEN
               TERM1 = EXP(-ABS(E-EE)/ALPHA1)
               TERM11 = TERM1/ALPHA1
            ELSE
               TERM1 = 0.0D+00
               TERM11 = 0.0D+00
            ENDIF
 
            IF ( ALPHA2.GT.0.0 ) THEN
               TERM2 = EXP(-ABS(E-EE)/ALPHA2)
               TERM22 = TERM2/ALPHA2
            ELSE
               TERM2 = 0.0D+00
               TERM22 = 0.0D+00
            ENDIF
 
            Fractt = DC(Mol,4) + DC(Mol,8)*E
 
            PDOWN = (1.0D00-Fractt)*TERM1 + Fractt*TERM2
            Hs = PDOWN/((1.0D00-Fractt)*TERM11+Fractt*TERM22)
            IF ( Hs.GT.MAX(ALPHA1,ALPHA2) ) THEN
               Hs = MAX(ALPHA1,ALPHA2)
c            ELSEIF ( Hs.LT.MIN(ALPHA1,ALPHA2) ) THEN
c               Hs = MIN(ALPHA1,ALPHA2)
c               Hs = MAX(Hs,Egrain1)
            ENDIF
 
 
            RETURN
         ELSEIF ( ITYPE(Mol).EQ.5 ) THEN
 
            ALPHA = ABS(DC(Mol,1)+(E*(DC(Mol,2)+E*DC(Mol,3))))
 
 
 
            EN = ABS(DC(Mol,5)+(E*(DC(Mol,6)+E*DC(Mol,7))))
 
            ARG = (ABS(E-EE)/ALPHA)**EN
 
            IF ( ARG.GT.100 ) THEN
               PDOWN = 0.
               Hs = 10000.      ! Take giant steps, because PDOWN=0, anyway
            ELSE
               PDOWN = EXP(-ARG)
               IF ( ALPHA.GT.0.0 ) THEN
                  Hs = ALPHA/EN
               ELSE
                  Hs = Egrain1
               ENDIF
            ENDIF
 
            RETURN
         ELSEIF ( ITYPE(Mol).EQ.6 ) THEN
 
            ALPHA1 = ABS(DC(Mol,1)+(E*(DC(Mol,2)+E*DC(Mol,3))))
 
 
 
            EN = ABS(DC(Mol,4)+E*(DC(Mol,5)))
            Fractt = DC(Mol,6)
            ALPHA2 = ABS(DC(Mol,7)+E*(DC(Mol,8)))
 
 
            IF ( ALPHA1.GT.0.0 ) THEN
               ARG = (ABS(E-EE)/ALPHA1)**EN
               IF ( ARG.GT.100. ) ARG = 100.
               TERM1 = EXP(-ARG)
               TERM11 = EN/ALPHA1
            ELSE
               TERM11 = 1.00D+00/Egrain1
            ENDIF
 
            IF ( ALPHA2.GT.0.0 ) THEN
               TERM2 = EXP(-ABS(E-EE)/ALPHA2)
               TERM22 = TERM2/ALPHA2
            ELSE
               TERM2 = 0.0D+00
               TERM22 = 0.0D+00
            ENDIF
 
            A = 1.0/TERM11
            B = 1.0/TERM22
 
            PDOWN = (1.0D00-Fractt)*TERM1 + Fractt*TERM2
            Hs = PDOWN/((1.0D00-Fractt)*TERM11+Fractt*TERM22)
            IF ( Hs.GT.MAX(A,B) ) THEN
               Hs = MAX(A,B)
c            ELSEIF ( Hs.LT.MIN(A,B) ) THEN
c               Hs = MIN(A,B)
c               Hs = MAX(Hs,Egrain1)
            ENDIF
 
            RETURN
         ELSEIF ( ITYPE(Mol).EQ.7 ) THEN
 
            ALPHA = ABS(DC(Mol,1)+(E*(DC(Mol,2)+E*DC(Mol,3))))  ! Energy units
 
 
            BET = DC(Mol,4) + E*DC(Mol,5)
 
            TT = ALPHA*BET
            IF ( TT.LE.0.0 ) THEN
               PAUSE 
     &           'Weibull Model requires ALPHA & BETA > 0; (hit return)'
               STOP
            ENDIF
 
            Rob_3 = 1.0
 
            Hs = MAX(ALPHA/BET,Rob_3)   ! Energy units
            ALPHA = ALPHA**BET          ! units for Weibull Distribution
            X = ABS(E-EE)
 
            IF ( X.GT.0.0 ) THEN        ! if X >0
               ARG2 = (X**(BET-2.))/ALPHA
               ARG1 = X*ARG2
               ARG = X*ARG1
               IF ( ARG.GT.100. ) THEN  ! then ARG1 and ARG2 must be even bigger
                  PDOWN = 0.0
                  Hs = 10000.   ! Take giant steps, because PDOWN = 0 anyway
                  RETURN
               ELSE
                  PDOWN = (BET/ALPHA)*ARG1*EXP(-ARG)
                                                ! This is General Weibull Model
                  RETURN
               ENDIF
            ELSEIF ( ABS(BET-1.0).LT.1.0E-06 ) THEN     ! if X=0 and BET=1, exponential model
               PDOWN = 1.0
               RETURN
            ELSE                        ! if X=0 and BET1
               PDOWN = 0.0
               RETURN
            ENDIF
         ELSEIF ( ITYPE(Mol).EQ.8 ) THEN
 
            ALPHA = ABS(DC(Mol,1)+(E*(DC(Mol,2)+E*DC(Mol,3))))
 
            WIDTH = ABS(DC(Mol,5)+(E*(DC(Mol,6)+E*DC(Mol,7))))
 
            X = (E-EE-ALPHA)
            PDOWN = WIDTH*WIDTH/(X*X+WIDTH*WIDTH)
 
            Hs = MIN(WIDTH/PDOWN,0.1*ALPHA)
            Hs = MAX(Hs,Egrain1)
 
            RETURN
         ELSEIF ( ITYPE(Mol).EQ.9 ) THEN
 
            ALPHA = ABS(DC(Mol,1)+(E*(DC(Mol,2)+E*DC(Mol,3)))
     &              *TEMPI**DC(Mol,8))
 
            F = DC(Mol,5) + ((E/DC(Mol,6))**DC(Mol,7))*TEMPI**DC(Mol,8)
 
            IF ( ALPHA.GT.0.0 ) THEN
               TERM1 = EXP(-ABS(E-EE)/ALPHA)
            ELSE
               TERM1 = 0.0D+00
            ENDIF
 
            IF ( ABS(EE-E).LT.1.0E-06 ) THEN                    ! Elastic collisions
               PDOWN = F*TERM1/(DC(Mol,4)+F) + DC(Mol,4)/(DC(Mol,4)+F)
            ELSE
               PDOWN = F*TERM1/(DC(Mol,4)+F)
            ENDIF
 
            Hs = MAX(ALPHA,Egrain1)
 
            RETURN
         ELSEIF ( ITYPE(Mol).EQ.10 ) THEN
 
            ALPHA = ABS(DC(Mol,1)+E*DC(Mol,2))
 
 
            BETA = ABS(DC(Mol,3))
 
            IF ( ALPHA.GT.0.0 ) THEN
               PDOWN = EXP(-(ABS((E-EE)/ALPHA))**BETA)
               Hs = ALPHA
            ELSE
               PDOWN = 0.0D+00
               Hs = 1.0
            ENDIF
 
            RETURN
         ELSEIF ( ITYPE(Mol).EQ.11 ) THEN
             ALPHA = ABS(DC(Mol,1)*(1-EXP(-((E/DC(Mol,2))**DC(Mol,3))))
     &        +DC(Mol,4))
 
            IF ( ALPHA.GT.0.0 ) THEN 
              TERM1 = EXP(-ABS(E-EE)/ALPHA)
              PDOWN = TERM1
              Hs = ALPHA
             ELSE
              PDOWN = 0.0D+00
              Hs = 1.0
            ENDIF
 
            RETURN
         ELSEIF ( ITYPE(Mol).EQ.12 ) THEN
 
            ALPHA1 = ABS( DC(Mol,1) + E*DC(Mol,2) + 
     &                DC(Mol,3)*EXP(-E/DC(Mol,4)) )

            IF ( ALPHA1.GT.0.0 ) THEN
               TERM1 = EXP(-ABS(E-EE)/ALPHA1)
               TERM11 = TERM1/ALPHA1
            ELSE
               TERM1 = 0.0D+00
               TERM11 = 0.0D+00
            ENDIF
 
            PDOWN = TERM1

            Hs = PDOWN/TERM11
            IF ( Hs.GT.ALPHA1 )  Hs = ALPHA1
c            IF (E .GT. Emax1+5.*Hs ) Hs = 5.*Hs    ! Big steps for exponential model at high E
 
            RETURN
         ELSEIF ( ITYPE(Mol).EQ.13 ) THEN
 
            ALPHA1 = ABS(DC(Mol,1) + E*DC(Mol,2))  ! Energy units
            ALPHA2 = ABS(DC(Mol,3) + E*DC(Mol,4))  ! Energy units
            BET = ALPHA1 + 0.5d+00*(ALPHA2 - ALPHA1)*(1.d+00 - 
     &             TANH((DC(Mol,5)-E)/DC(Mol,6)))                    ! Switching function

            TERM1 = EXP(-ABS(E-EE)/BET)
            TERM11 = TERM1/BET
 
            PDOWN = TERM1

            Hs = PDOWN/TERM11
            IF ( Hs.GT.BET )  Hs = BET
c            IF (E .GT. Emax1+5.*Hs ) Hs = 5.*Hs    ! Big steps for exponential model at high E

            RETURN
         ENDIF
      ENDIF
 
      ALPHA1 = ABS(DC(Mol,1)+(E*(DC(Mol,2)+E*DC(Mol,3)))
     &         *TEMPI**DC(Mol,8))
 
      ALPHA2 = ABS(DC(Mol,5)+(E*(DC(Mol,6)+E*DC(Mol,7)))
     &         *TEMPI**DC(Mol,8))
 
      IF ( ALPHA1.GT.0.0 ) THEN
         TERM1 = EXP(-ABS(E-EE)/ALPHA1)
         TERM11 = TERM1/ALPHA1
      ELSE
         TERM1 = 0.0D+00
         TERM11 = 0.0D+00
      ENDIF
 
      IF ( ALPHA2.GT.0.0 ) THEN
         TERM2 = EXP(-ABS(E-EE)/ALPHA2)
         TERM22 = TERM2/ALPHA2
      ELSE
         TERM2 = 0.0D+00
         TERM22 = 0.0D+00
      ENDIF
 
      PDOWN = (1.0D00-DC(Mol,4))*TERM1 + DC(Mol,4)*TERM2
      Hs = PDOWN/((1.0D00-DC(Mol,4))*TERM11+DC(Mol,4)*TERM22)

c      IF ( Hs.GT.MAX(ALPHA1,ALPHA2) ) THEN
c         Hs = MAX(ALPHA1,ALPHA2)
c      ELSEIF ( Hs.LT.MIN(ALPHA1,ALPHA2) ) THEN
c         Hs = MIN(ALPHA1,ALPHA2)
c      ENDIF
 
c      IF (E .GT. Emax1+5.*Hs .AND. DC(Mol,4) .LT. 1.e-6 ) THEN
c         Hs = 5.*Hs                   ! Big steps for exponential model at high E
c      ENDIF

      RETURN
  
      END
